@@ -141,5 +141,5 @@ class HTTPRequest(Request):
 		return self._data
 
 
-class ParseError(Exception):
+class InputParseError(Exception):
 	pass
