@@ -82,6 +82,8 @@ class HTTPRoute(WSRoute):
 				if item[0].match(path):
 					methods = item[2]
 					break
+		if not len(methods):
+			response.abort(status=404)
 		response.headers.append((b"Access-Control-Allow-Headers", b"*"))
 		response.headers.append((b"Access-Control-Allow-Methods", ",".join(methods).encode()))
 		response.headers.append((b"Vary", b"Access-Control-Request-Headers"))
